@@ -1,4 +1,4 @@
-# Copyright 2014 Hewlett-Packard Development Company, L.P.
+# Copyright 2018 Hewlett-Packard Development Company, L.P.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -25,12 +25,17 @@ from proliantutils.redfish import redfish
 SUPPORTED_RIS_METHODS = [
     'activate_license',
     'clear_secure_boot_keys',
+    'delete_raid_configuration',
     'eject_virtual_media',
+    'get_current_bios_settings',
     'get_current_boot_mode',
+    'get_host_post_state',
+    'get_default_bios_settings',
     'get_host_power_status',
     'get_http_boot_url',
     'get_ilo_firmware_version_as_major_minor',
     'get_one_time_boot',
+    'get_pending_bios_settings',
     'get_pending_boot_mode',
     'get_persistent_boot_device',
     'get_product_name',
@@ -39,12 +44,14 @@ SUPPORTED_RIS_METHODS = [
     'get_supported_boot_mode',
     'get_vm_status',
     'hold_pwr_btn',
+    'inject_nmi',
     'insert_virtual_media',
     'press_pwr_btn',
     'reset_bios_to_default',
     'reset_ilo_credential',
     'reset_secure_boot_keys',
     'reset_server',
+    'set_bios_settings',
     'set_host_power',
     'set_http_boot_url',
     'set_one_time_boot',
@@ -62,17 +69,24 @@ SUPPORTED_RIS_METHODS = [
     ]
 
 SUPPORTED_REDFISH_METHODS = [
+    'delete_raid_configuration',
     'get_product_name',
+    'get_host_post_state',
     'get_host_power_status',
     'set_host_power',
     'reset_server',
     'press_pwr_btn',
     'hold_pwr_btn',
+    'get_current_bios_settings',
+    'get_default_bios_settings',
+    'get_pending_bios_settings',
+    'set_bios_settings',
     'get_one_time_boot',
     'get_pending_boot_mode',
     'get_current_boot_mode',
     'activate_license',
     'eject_virtual_media',
+    'inject_nmi',
     'insert_virtual_media',
     'set_vm_status',
     'update_firmware',
@@ -629,6 +643,15 @@ class IloClient(operations.IloOperations):
         """
         return self._call_method('activate_license', key)
 
+    def delete_raid_configuration(self):
+        """Deletes the logical drives from the system
+
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        return self._call_method('delete_raid_configuration')
+
     def update_firmware(self, firmware_url, component_type):
         """Updates the given firmware on the server
 
@@ -641,3 +664,94 @@ class IloClient(operations.IloOperations):
         """
         return self._call_method(
             'update_firmware', firmware_url, component_type)
+
+    def inject_nmi(self):
+        """Inject NMI, Non Maskable Interrupt.
+
+        Inject NMI (Non Maskable Interrupt) for a node immediately.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloConnectionError, if not able to reach iLO.
+        :raises: IloCommandNotSupportedError, if the command is
+                 not supported on the server
+        """
+        return self._call_method('inject_nmi')
+
+    def get_host_post_state(self):
+        """Request the current state of system POST.
+
+        Retrieves current state of system POST.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloCommandNotSupportedError, if the command is
+                 not supported on the server
+        """
+        return self._call_method('get_host_post_state')
+
+    def get_current_bios_settings(self, only_allowed_settings=True):
+        """Get current BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of current BIOS settings is returned. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        return self._call_method('get_current_bios_settings',
+                                 only_allowed_settings)
+
+    def get_pending_bios_settings(self, only_allowed_settings=True):
+        """Get current BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of pending BIOS settings. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        return self._call_method('get_pending_bios_settings',
+                                 only_allowed_settings)
+
+    def set_bios_settings(self, data=None, only_allowed_settings=True):
+        """Sets current BIOS settings to the provided data.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be set. If False, all the BIOS settings supported by
+                iLO and present in the 'data' are set.
+        :param: data: a dictionary of BIOS settings to be applied. Depending
+                on the 'only_allowed_settings', either only the allowed
+                settings are set or all the supported settings that are in the
+                'data' are set.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        return self._call_method('set_bios_settings', data,
+                                 only_allowed_settings)
+
+    def get_default_bios_settings(self, only_allowed_settings=True):
+        """Get default BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of default BIOS settings(factory settings).
+                 Depending on the 'only_allowed_settings', either only
+                 the allowed settings are returned or all the supported
+                 settings are returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        return self._call_method('get_default_bios_settings',
+                                 only_allowed_settings)
