@@ -1,4 +1,4 @@
-# Copyright 2014 Hewlett-Packard Development Company, L.P.
+# Copyright 2018 Hewlett-Packard Development Company, L.P.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -1183,6 +1183,43 @@ class RIBCLOperations(operations.IloOperations):
             if location == 'Embedded':
                 nic_dict[port] = mac
 
+    def _raise_command_not_supported(self, method):
+        platform = self.get_product_name()
+        msg = ("`%(method)s` is not supported on %(platform)s" %
+               {'method': method, 'platform': platform})
+        raise (exception.IloCommandNotSupportedError(msg))
+
+    def inject_nmi(self):
+        """Inject NMI, Non Maskable Interrupt.
+
+        Inject NMI (Non Maskable Interrupt) for a node immediately.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloCommandNotSupportedError
+        """
+        self._raise_command_not_supported("inject_nmi")
+
+    def get_host_post_state(self):
+        """Request the current state of system POST.
+
+        Retrieves current state of system POST.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloCommandNotSupportedError, RIBCL do not support it.
+        """
+        self._raise_command_not_supported("get_host_post_state")
+
+    def delete_raid_configuration(self):
+        """Delete the raid configuration on the hardware.
+
+        Loops through each SmartStorageConfig controller and clears the
+        raid configuration.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloCommandNotSupportedError
+        """
+        self._raise_command_not_supported("delete_raid_configuration")
+
 
 # The below block of code is there only for backward-compatibility
 # reasons (before commit 47608b6 for ris-support).
