@@ -1,4 +1,4 @@
-# Copyright 2017 Hewlett Packard Enterprise Development Company, L.P.
+# Copyright 2018 Hewlett Packard Enterprise Development Company, L.P.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,11 +19,13 @@ import retrying
 
 from proliantutils import exception
 from proliantutils.ilo import common
+from proliantutils.ilo import constants
 from proliantutils.ilo import firmware_controller
 from proliantutils.ilo import mappings
 from proliantutils.ilo import operations
 from proliantutils import log
 from proliantutils import rest
+from proliantutils import utils
 
 """ Currently this class supports only secure boot and firmware settings
 related API's .
@@ -789,7 +791,8 @@ class RISOperations(rest.RestConnectorBase, operations.IloOperations):
         """Perform requested power operation.
 
         :param oper: Type of power button press to simulate.
-                     Supported values: 'ON', 'ForceOff' and 'ForceRestart'
+                     Supported values: 'ON', 'ForceOff', 'ForceRestart' and
+                     'Nmi'
         :raises: IloError, on an error from iLO.
         """
 
@@ -886,7 +889,7 @@ class RISOperations(rest.RestConnectorBase, operations.IloOperations):
             LOG.debug(self._("Node is already in '%(power)s' power state."),
                       {'power': power})
             return
-        if power == 'ON' and 'Proliant BL' in self.get_product_name():
+        if power == 'ON' and 'PROLIANT BL' in self.get_product_name().upper():
             self._retry_until_powered_on(power)
         else:
             self._perform_power_op(POWER_STATE[power])
@@ -1820,3 +1823,171 @@ class RISOperations(rest.RestConnectorBase, operations.IloOperations):
         except exception.IloCommandNotSupportedError:
             nvn_status = False
         return nvn_status
+
+    def inject_nmi(self):
+        """Inject NMI, Non Maskable Interrupt.
+
+        Inject NMI (Non Maskable Interrupt) for a node immediately.
+
+        :raises: IloError, on an error from iLO
+        """
+        cur_status = self.get_host_power_status()
+        if cur_status != 'ON':
+            raise exception.IloError("Server is not in powered on state.")
+
+        self._perform_power_op("Nmi")
+
+    def get_host_post_state(self):
+        """Get the current state of system POST.
+
+        Retrieves current state of system POST.
+
+        :returns: POST state of the server. The valida states are:-
+                  null, Unknown, Reset, PowerOff, InPost,
+                  InPostDiscoveryComplete and FinishedPost.
+        :raises: IloError, on an error from iLO
+        """
+        system = self._get_host_details()
+        if 'PostState' in system['Oem']['Hp']:
+            return system['Oem']['Hp']['PostState']
+        raise exception.IloError("Attribute 'Oem/Hp/PostState' "
+                                 "not found on system.")
+
+    def get_current_bios_settings(self, only_allowed_settings=True):
+        """Get current BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of current BIOS settings is returned. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        headers, bios_uri, bios_settings = self._check_bios_resource()
+        # Remove the "links" section
+        bios_settings.pop("links", None)
+        if only_allowed_settings:
+            return utils.apply_bios_properties_filter(
+                bios_settings, constants.SUPPORTED_BIOS_PROPERTIES)
+        return bios_settings
+
+    def get_pending_bios_settings(self, only_allowed_settings=True):
+        """Get current BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of pending BIOS settings. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        headers, bios_uri, bios_settings = self._check_bios_resource()
+        try:
+            settings_config_uri = bios_settings['links']['Settings']['href']
+        except KeyError:
+            msg = ("Settings resource not found. Couldn't get pending BIOS "
+                   "Settings.")
+            raise exception.IloCommandNotSupportedError(msg)
+
+        status, headers, config = self._rest_get(settings_config_uri)
+        if status != 200:
+            msg = self._get_extended_error(config)
+            raise exception.IloError(msg)
+
+        # Remove the "links" section
+        config.pop("links", None)
+
+        if only_allowed_settings:
+            return utils.apply_bios_properties_filter(
+                config, constants.SUPPORTED_BIOS_PROPERTIES)
+        return config
+
+    def set_bios_settings(self, data=None, only_allowed_settings=True):
+        """Sets current BIOS settings to the provided data.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be set. If False, all the BIOS settings supported by
+                iLO and present in the 'data' are set.
+        :param: data: a dictionary of BIOS settings to be applied. Depending
+                on the 'only_allowed_settings', either only the allowed
+                settings are set or all the supported settings that are in
+                the 'data' are set.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        if only_allowed_settings and data:
+            refined_data = utils.apply_bios_properties_filter(
+                data, constants.SUPPORTED_BIOS_PROPERTIES)
+            self._change_bios_setting(refined_data)
+            return
+
+        if data:
+            self._change_bios_setting(data)
+
+    def get_default_bios_settings(self, only_allowed_settings=True):
+        """Get default BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of default BIOS settings(factory settings).
+                 Depending on the 'only_allowed_settings', either only the
+                 allowed settings are returned or all the supported settings
+                 are returned.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        headers_bios, bios_uri, bios_settings = self._check_bios_resource()
+        # Get the BaseConfig resource.
+        try:
+            base_config_uri = bios_settings['links']['BaseConfigs']['href']
+        except KeyError:
+            msg = ("BaseConfigs resource not found. Couldn't apply the BIOS "
+                   "Settings.")
+            raise exception.IloCommandNotSupportedError(msg)
+
+        status, headers, config = self._rest_get(base_config_uri)
+        if status != 200:
+            msg = self._get_extended_error(config)
+            raise exception.IloError(msg)
+
+        for cfg in config['BaseConfigs']:
+            default_settings = cfg.get('default')
+            if default_settings:
+                break
+        else:
+            msg = ("Default BIOS Settings not found in 'BaseConfigs' "
+                   "resource.")
+            raise exception.IloCommandNotSupportedError(msg)
+
+        if only_allowed_settings:
+            return utils.apply_bios_properties_filter(
+                default_settings, constants.SUPPORTED_BIOS_PROPERTIES)
+        return default_settings
+
+    def _raise_command_not_supported(self, method):
+        platform = self.get_product_name()
+        msg = ("`%(method)s` is not supported on %(platform)s" %
+               {'method': method, 'platform': platform})
+        raise (exception.IloCommandNotSupportedError(msg))
+
+    def delete_raid_configuration(self):
+        """Delete the raid configuration on the hardware.
+
+        Loops through each SmartStorageConfig controller and clears the
+        raid configuration.
+
+        :raises: IloError, on an error from iLO
+        :raises: IloCommandNotSupportedError
+        """
+        self._raise_command_not_supported("delete_raid_configuration")
