@@ -15,6 +15,7 @@
 from ironic_python_agent import hardware
 
 from proliantutils.hpssa import manager as hpssa_manager
+from proliantutils.sum import sum_controller
 
 
 class ProliantHardwareManager(hardware.GenericHardwareManager):
@@ -40,6 +41,12 @@ class ProliantHardwareManager(hardware.GenericHardwareManager):
                  'priority': 0},
                 {'step': 'delete_configuration',
                  'interface': 'raid',
+                 'priority': 0},
+                {'step': 'erase_devices',
+                 'interface': 'deploy',
+                 'priority': 0},
+                {'step': 'update_firmware_sum',
+                 'interface': 'management',
                  'priority': 0}]
 
     def evaluate_hardware_support(cls):
@@ -80,3 +87,37 @@ class ProliantHardwareManager(hardware.GenericHardwareManager):
             for the node
         """
         return hpssa_manager.delete_configuration()
+
+    def erase_devices(self, node, port):
+        """Erase the drives on the bare metal.
+
+        This method erase all the drives which supports sanitize and the drives
+        which are not part of any logical volume on the bare metal. It calls
+        generic erase method after the success of Sanitize disk erase.
+        :param node: A dictionary of the node object.
+        :param port: A list of dictionaries containing information of ports
+            for the node.
+        :raises exception.HPSSAOperationError, if there is a failure on the
+            erase operation on the controllers.
+        :returns: The dictionary of controllers with the drives and erase
+            status for each drive.
+        """
+        result = {}
+        result['Disk Erase Status'] = hpssa_manager.erase_devices()
+
+        result.update(super(ProliantHardwareManager,
+                            self).erase_devices(node, port))
+        return result
+
+    def update_firmware_sum(self, node, port):
+        """Performs SUM based firmware update on the bare metal node.
+
+        This method performs firmware update on all or some of the firmware
+        components on the bare metal node.
+
+        :returns: A string with return code and the statistics of
+            updated/failed components.
+        :raises: SUMOperationError, when the SUM based firmware update
+            operation on the node fails.
+        """
+        return sum_controller.update_firmware(node)
