@@ -1,4 +1,4 @@
-# Copyright 2017 Hewlett Packard Enterprise Development LP
+# Copyright 2018 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,6 +18,7 @@ import json
 
 from six.moves.urllib import parse
 import sushy
+from sushy import auth
 from sushy.resources.system import mappings as sushy_map
 from sushy import utils
 
@@ -32,6 +33,7 @@ from proliantutils.redfish.resources.system import constants as sys_cons
 from proliantutils.redfish.resources.system.storage \
     import common as common_storage
 from proliantutils.redfish import utils as rf_utils
+from proliantutils import utils as common_utils
 
 """
 Class specific for Redfish APIs.
@@ -80,6 +82,16 @@ GET_SECUREBOOT_CURRENT_BOOT_MAP = {
     sys_cons.SECUREBOOT_CURRENT_BOOT_DISABLED: False
 }
 
+GET_POST_STATE_MAP = {
+    sys_cons.POST_STATE_NULL: 'Null',
+    sys_cons.POST_STATE_UNKNOWN: 'Unknown',
+    sys_cons.POST_STATE_RESET: 'Reset',
+    sys_cons.POST_STATE_POWEROFF: 'PowerOff',
+    sys_cons.POST_STATE_INPOST: 'InPost',
+    sys_cons.POST_STATE_INPOSTDISCOVERY: 'InPostDiscoveryComplete',
+    sys_cons.POST_STATE_FINISHEDPOST: 'FinishedPost'
+}
+
 # Assuming only one system and one manager present as part of
 # collection, as we are dealing with iLO's here.
 PROLIANT_MANAGER_ID = '1'
@@ -141,9 +153,10 @@ class RedfishOperations(operations.IloOperations):
         self._username = username
 
         try:
+            basic_auth = auth.BasicAuth(username=username, password=password)
             self._sushy = main.HPESushy(
-                address, username=username, password=password,
-                root_prefix=root_prefix, verify=verify)
+                address, root_prefix=root_prefix, verify=verify,
+                auth=basic_auth)
         except sushy.exceptions.SushyError as e:
             msg = (self._('The Redfish controller at "%(controller)s" has '
                           'thrown error. Error %(error)s') %
@@ -665,9 +678,7 @@ class RedfishOperations(operations.IloOperations):
                 ('trusted_boot',
                  (tpm_state == sys_cons.TPM_PRESENT_ENABLED
                   or tpm_state == sys_cons.TPM_PRESENT_DISABLED)),
-                ('secure_boot',
-                 GET_SECUREBOOT_CURRENT_BOOT_MAP.get(
-                     sushy_system.secure_boot.current_boot)),
+                ('secure_boot', self._has_secure_boot()),
                 ('iscsi_boot',
                  (sushy_system.bios_settings.iscsi_resource.
                   is_iscsi_boot_supported())),
@@ -756,6 +767,13 @@ class RedfishOperations(operations.IloOperations):
             LOG.debug(self._("Secure boot is Disabled"))
         return secure_boot_enabled
 
+    def _has_secure_boot(self):
+        try:
+            self._get_sushy_system(PROLIANT_SYSTEM_ID).secure_boot
+        except (exception.MissingAttributeError, sushy.exceptions.SushyError):
+            return False
+        return True
+
     def set_secure_boot_mode(self, secure_boot_enable):
         """Enable/Disable secure boot on the server.
 
@@ -1001,3 +1019,152 @@ class RedfishOperations(operations.IloOperations):
         else:
             msg = 'iSCSI initiator cannot be retrieved in BIOS boot mode'
             raise exception.IloCommandNotSupportedInBiosError(msg)
+
+    def inject_nmi(self):
+        """Inject NMI, Non Maskable Interrupt.
+
+        Inject NMI (Non Maskable Interrupt) for a node immediately.
+
+        :raises: IloError, on an error from iLO
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        if sushy_system.power_state != sushy.SYSTEM_POWER_STATE_ON:
+            raise exception.IloError("Server is not in powered on state.")
+
+        try:
+            sushy_system.reset_system(sushy.RESET_NMI)
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('The Redfish controller failed to inject nmi to '
+                          'server. Error %(error)s') % {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+
+    def get_host_post_state(self):
+        """Get the current state of system POST.
+
+        Retrieves current state of system POST.
+
+        :returns: POST state of the server. The valida states are:-
+                  null, Unknown, Reset, PowerOff, InPost,
+                  InPostDiscoveryComplete and FinishedPost.
+        :raises: IloError, on an error from iLO
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        return GET_POST_STATE_MAP.get(sushy_system.post_state)
+
+    def delete_raid_configuration(self):
+        """Delete the raid configuration on the hardware."""
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        sushy_system.delete_raid()
+
+    def get_current_bios_settings(self, only_allowed_settings=True):
+        """Get current BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of current BIOS settings is returned. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        try:
+            current_settings = sushy_system.bios_settings.json
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('The current BIOS Settings were not found. Error '
+                          '%(error)s') %
+                   {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+
+        attributes = current_settings.get("Attributes")
+        if only_allowed_settings and attributes:
+            return common_utils.apply_bios_properties_filter(
+                attributes, ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES)
+        return attributes
+
+    def get_pending_bios_settings(self, only_allowed_settings=True):
+        """Get pending BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings are
+                to be returned. If False, All the BIOS settings supported by
+                iLO are returned.
+        :return: a dictionary of pending BIOS settings is returned. Depending
+                 on the 'only_allowed_settings', either only the allowed
+                 settings are returned or all the supported settings are
+                 returned.
+        :raises: IloError, on an error from iLO.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        try:
+            settings = sushy_system.bios_settings.pending_settings.json
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('The pending BIOS Settings were not found. Error '
+                          '%(error)s') %
+                   {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+
+        attributes = settings.get("Attributes")
+        if only_allowed_settings and attributes:
+            return common_utils.apply_bios_properties_filter(
+                attributes, ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES)
+        return attributes
+
+    def set_bios_settings(self, data=None, only_allowed_settings=True):
+        """Sets current BIOS settings to the provided data.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be set. If False, all the BIOS settings supported by
+                iLO and present in the 'data' are set.
+        :param: data: a dictionary of BIOS settings to be applied. Depending
+                on the 'only_allowed_settings', either only the allowed
+                settings are set or all the supported settings that are in the
+                'data' are set.
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is not supported
+                 on the server.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        filtered_data = data
+        if only_allowed_settings and data:
+            filtered_data = common_utils.apply_bios_properties_filter(
+                data, ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES)
+        if filtered_data:
+            try:
+                settings_required = sushy_system.bios_settings.pending_settings
+                settings_required.update_bios_data_by_patch(filtered_data)
+            except sushy.exceptions.SushyError as e:
+                msg = (self._('The pending BIOS Settings resource not found.'
+                              ' Error %(error)s') %
+                       {'error': str(e)})
+                LOG.debug(msg)
+                raise exception.IloError(msg)
+
+    def get_default_bios_settings(self, only_allowed_settings=True):
+        """Get default BIOS settings.
+
+        :param: only_allowed_settings: True when only allowed BIOS settings
+                are to be returned. If False, All the BIOS settings supported
+                by iLO are returned.
+        :return: a dictionary of default BIOS settings(factory settings).
+                 Depending on the 'only_allowed_settings', either only the
+                 allowed settings are returned or all the supported settings
+                 are returned.
+        :raises: IloError, on an error from iLO.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        try:
+            settings = sushy_system.bios_settings.default_settings
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('The default BIOS Settings were not found. Error '
+                          '%(error)s') %
+                   {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+        if only_allowed_settings:
+            return common_utils.apply_bios_properties_filter(
+                settings, ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES)
+        return settings
