@@ -756,6 +756,29 @@ class IloClientTestCase(testtools.TestCase):
         self.client.activate_license('fake-key')
         call_mock.assert_called_once_with('activate_license', 'fake-key')
 
+    @mock.patch.object(client.IloClient, '_call_method')
+    def test_delete_raid_configuration(self, call_mock):
+        self.client.delete_raid_configuration()
+        call_mock.assert_called_once_with('delete_raid_configuration')
+
+    @mock.patch.object(ris.RISOperations, 'get_product_name')
+    def test_delete_raid_configuration_gen9(self, get_product_mock):
+        self.client.model = 'Gen9'
+        get_product_mock.return_value = 'ProLiant BL460c Gen9'
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                '`delete_raid_configuration` is not supported '
+                                'on ProLiant BL460c Gen9',
+                                self.client.delete_raid_configuration)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_product_name')
+    def test_delete_raid_configuration_gen8(self, get_product_mock):
+        self.client.model = 'Gen8'
+        get_product_mock.return_value = 'ProLiant DL380 G8'
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                '`delete_raid_configuration` is not supported '
+                                'on ProLiant DL380 G8',
+                                self.client.delete_raid_configuration)
+
     @mock.patch.object(ris.RISOperations, 'eject_virtual_media')
     def test_eject_virtual_media_gen9(self, eject_virtual_media_mock):
         self.client.model = 'Gen9'
@@ -920,6 +943,35 @@ class IloClientTestCase(testtools.TestCase):
         self.client.reset_server()
         self.assertTrue(reset_server_mock.called)
 
+    @mock.patch.object(ris.RISOperations, 'get_current_bios_settings')
+    def test_get_current_bios_settings_gen9(self, cur_bios_settings_mock):
+        self.client.model = 'Gen9'
+        apply_filter = True
+        self.client.get_current_bios_settings(apply_filter)
+        cur_bios_settings_mock.assert_called_once_with(True)
+
+    @mock.patch.object(ris.RISOperations, 'get_pending_bios_settings')
+    def test_get_pending_bios_settings_gen9(self, pending_bios_settings_mock):
+        self.client.model = 'Gen9'
+        apply_filter = True
+        self.client.get_pending_bios_settings(apply_filter)
+        pending_bios_settings_mock.assert_called_once_with(True)
+
+    @mock.patch.object(ris.RISOperations, 'get_default_bios_settings')
+    def test_get_default_bios_settings_gen9(self, def_bios_settings_mock):
+        self.client.model = 'Gen9'
+        apply_filter = False
+        self.client.get_default_bios_settings(apply_filter)
+        def_bios_settings_mock.assert_called_once_with(False)
+
+    @mock.patch.object(ris.RISOperations, 'set_bios_settings')
+    def test_set_bios_settings_gen9(self, bios_settings_mock):
+        self.client.model = 'Gen9'
+        apply_filter = False
+        d = {'a': 'blah', 'b': 'blah blah'}
+        self.client.set_bios_settings(d, apply_filter)
+        bios_settings_mock.assert_called_once_with(d, False)
+
     @mock.patch.object(client.IloClient, '_call_method')
     @mock.patch.object(snmp_cpqdisk_sizes, 'get_local_gb')
     def test_get_essential_prop_no_snmp_ris(self,
@@ -1011,6 +1063,41 @@ class IloClientTestCase(testtools.TestCase):
         call_mock.assert_called_once_with('get_essential_properties')
         self.assertFalse(snmp_mock.called)
 
+    @mock.patch.object(client.IloClient, '_call_method')
+    def test_inject_nmi(self, call_mock):
+        self.client.inject_nmi()
+        call_mock.assert_called_once_with('inject_nmi')
+
+    @mock.patch.object(ris.RISOperations, 'inject_nmi')
+    def test_inject_nmi_gen9(self, inject_nmi_mock):
+        self.client.model = 'Gen9'
+        self.client.inject_nmi()
+        inject_nmi_mock.assert_called_once_with()
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_product_name')
+    def test_inject_nmi_gen8(self, product_mock):
+        self.client.model = 'Gen8'
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                'not supported',
+                                self.client.inject_nmi)
+
+    @mock.patch.object(client.IloClient, '_call_method')
+    def test_get_host_post_state(self, call_mock):
+        self.client.get_host_post_state()
+        call_mock.assert_called_once_with('get_host_post_state')
+
+    @mock.patch.object(ris.RISOperations, 'get_host_post_state')
+    def test_get_host_post_state_gen9(self, get_host_post_state_mock):
+        self.client.model = 'Gen9'
+        self.client.get_host_post_state()
+        get_host_post_state_mock.assert_called_once_with()
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_host_post_state')
+    def test_get_host_post_state_gen8(self, get_host_post_state_mock):
+        self.client.model = 'Gen8'
+        self.client.get_host_post_state()
+        get_host_post_state_mock.assert_called_once_with()
+
 
 class IloRedfishClientTestCase(testtools.TestCase):
 
