@@ -1041,6 +1041,27 @@ class IloRibclTestCaseBeforeRisSupport(unittest.TestCase):
         self.ilo.set_vm_status('cdrom', 'boot_once', 'yes')
         self.assertTrue(request_ilo_mock.called)
 
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_product_name')
+    def test_inject_nmi(self, product_name_mock):
+        product_name_mock.return_value = constants.GET_PRODUCT_NAME
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                'ProLiant DL380 G7',
+                                self.ilo.inject_nmi)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_product_name')
+    def test_get_host_post_state(self, product_name_mock):
+        product_name_mock.return_value = constants.GET_PRODUCT_NAME
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                'ProLiant DL380 G7',
+                                self.ilo.get_host_post_state)
+
+    @mock.patch.object(ribcl.RIBCLOperations, 'get_product_name')
+    def test_delete_raid_configuration(self, product_name_mock):
+        product_name_mock.return_value = constants.GET_PRODUCT_NAME
+        self.assertRaisesRegexp(exception.IloCommandNotSupportedError,
+                                'ProLiant DL380 G7',
+                                self.ilo.delete_raid_configuration)
+
 
 if __name__ == '__main__':
     unittest.main()
