@@ -21,6 +21,9 @@ import mock
 import sushy
 import testtools
 
+from sushy import auth
+from sushy.resources.system import system
+
 from proliantutils import exception
 from proliantutils.ilo import constants as ilo_cons
 from proliantutils.redfish import main
@@ -38,7 +41,7 @@ from proliantutils.redfish.resources.system.storage import array_controller
 from proliantutils.redfish.resources.system.storage \
     import common as common_storage
 from proliantutils.redfish.resources.system import system as pro_sys
-from sushy.resources.system import system
+from proliantutils import utils
 
 
 @ddt.ddt
@@ -59,8 +62,11 @@ class RedfishOperationsTestCase(testtools.TestCase):
 
         self.rf_client = redfish.RedfishOperations(
             '1.2.3.4', username='foo', password='bar')
-        sushy_mock.assert_called_once_with(
-            'https://1.2.3.4', 'foo', 'bar', '/redfish/v1/', False)
+        args, kwargs = sushy_mock.call_args
+        self.assertEqual(('https://1.2.3.4',), args)
+        self.assertFalse(kwargs.get('verify'))
+        self.assertEqual('/redfish/v1/', kwargs.get('root_prefix'))
+        self.assertIsInstance(kwargs.get('auth'), auth.BasicAuth)
 
     @mock.patch.object(main, 'HPESushy', autospec=True)
     def test_sushy_init_fail(self, sushy_mock):
@@ -486,7 +492,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
                                              _uefi_boot_mode_mock):
         _uefi_boot_mode_mock.return_value = False
         result = self.rf_client.get_persistent_boot_device()
-        self.assertEqual(result, None)
+        self.assertIsNone(result)
 
     @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
     def test_get_persistent_boot_device_cdrom_continuous(self,
@@ -699,8 +705,8 @@ class RedfishOperationsTestCase(testtools.TestCase):
             sys_cons.SRIOV_ENABLED)
         type(get_system_mock.return_value.bios_settings).cpu_vt = (
             sys_cons.CPUVT_ENABLED)
-        type(get_system_mock.return_value.secure_boot).current_boot = (
-            sys_cons.SECUREBOOT_CURRENT_BOOT_ENABLED)
+        type(get_system_mock.return_value).secure_boot = (
+            mock.MagicMock(spec='Hey I am secure_boot'))
         type(get_system_mock.return_value).rom_version = (
             'U31 v1.00 (03/11/2017)')
         type(get_manager_mock.return_value).firmware_version = 'iLO 5 v1.15'
@@ -774,8 +780,8 @@ class RedfishOperationsTestCase(testtools.TestCase):
             sys_cons.SRIOV_DISABLED)
         type(get_system_mock.return_value.bios_settings).cpu_vt = (
             sys_cons.CPUVT_DISABLED)
-        type(get_system_mock.return_value.secure_boot).current_boot = (
-            sys_cons.SECUREBOOT_CURRENT_BOOT_DISABLED)
+        type(get_system_mock.return_value).secure_boot = (
+            mock.PropertyMock(side_effect=exception.MissingAttributeError))
         type(get_system_mock.return_value).rom_version = (
             'U31 v1.00 (03/11/2017)')
         type(get_manager_mock.return_value).firmware_version = 'iLO 5 v1.15'
@@ -901,6 +907,21 @@ class RedfishOperationsTestCase(testtools.TestCase):
             'information about secure boot on the server.',
             self.rf_client.get_secure_boot_mode)
 
+    def test__has_secure_boot(self):
+        sushy_system_mock = self.sushy.get_system.return_value
+        type(sushy_system_mock).secure_boot = mock.PropertyMock(
+            return_value='Hey I am secure_boot')
+        self.assertTrue(self.rf_client._has_secure_boot())
+
+    def test__has_secure_boot_on_fail(self):
+        sushy_system_mock = self.sushy.get_system.return_value
+        type(sushy_system_mock).secure_boot = mock.PropertyMock(
+            side_effect=sushy.exceptions.SushyError)
+        self.assertFalse(self.rf_client._has_secure_boot())
+        type(sushy_system_mock).secure_boot = mock.PropertyMock(
+            side_effect=exception.MissingAttributeError)
+        self.assertFalse(self.rf_client._has_secure_boot())
+
     @mock.patch.object(redfish.RedfishOperations, '_is_boot_mode_uefi',
                        autospec=True)
     def test_set_secure_boot_mode(self, _is_boot_mode_uefi_mock):
@@ -1404,3 +1425,253 @@ class RedfishOperationsTestCase(testtools.TestCase):
                                'iSCSI initiator cannot be retrieved in '
                                'BIOS boot mode',
                                self.rf_client.get_iscsi_initiator_info)
+
+    def test_inject_nmi(self):
+        self.sushy.get_system().power_state = sushy.SYSTEM_POWER_STATE_ON
+        self.rf_client.inject_nmi()
+        self.sushy.get_system().reset_system.assert_called_once_with(
+            sushy.RESET_NMI)
+
+    def test_inject_nmi_power_off(self):
+        self.sushy.get_system().power_state = sushy.SYSTEM_POWER_STATE_OFF
+        self.assertRaisesRegex(
+            exception.IloError,
+            'Server is not in powered on state.',
+            self.rf_client.inject_nmi)
+        self.assertFalse(self.sushy.get_system().reset_system.called)
+
+    def test_inject_nmi_sushy_exc(self):
+        self.sushy.get_system().power_state = sushy.SYSTEM_POWER_STATE_ON
+        self.sushy.get_system().reset_system.side_effect = (
+            sushy.exceptions.SushyError)
+        self.assertRaisesRegex(
+            exception.IloError,
+            'The Redfish controller failed to inject nmi',
+            self.rf_client.inject_nmi)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_current_bios_settings_filter_true(self, get_system_mock):
+
+        only_allowed_settings = True
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("Default")
+        type(
+            get_system_mock.return_value.bios_settings).json = (
+                mock.PropertyMock(return_value=jsonval))
+        settings = jsonval.get('Attributes')
+        expected_value = {k: settings[k] for k in (
+            ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES) if k in settings}
+        actual_value = self.rf_client.get_current_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected_value, actual_value)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_current_bios_settings_filter_false(self, get_system_mock):
+
+        only_allowed_settings = False
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("Default")
+        type(
+            get_system_mock.return_value.bios_settings).json = (
+                mock.PropertyMock(return_value=jsonval))
+        settings = jsonval.get('Attributes')
+        expected_value = settings
+        actual_value = self.rf_client.get_current_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected_value, actual_value)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_current_bios_settings_raises_exception(self, get_system_mock):
+
+        only_allowed_settings = True
+        bios_mock = mock.PropertyMock()
+        bios_mock.side_effect = sushy.exceptions.SushyError
+        type(get_system_mock.return_value.bios_settings).json = bios_mock
+        self.assertRaisesRegex(
+            exception.IloError,
+            'The current BIOS Settings were not found',
+            self.rf_client.get_current_bios_settings,
+            only_allowed_settings)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_pending_bios_settings_filter_true(self, system_mock):
+
+        only_allowed_settings = True
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("BIOS_pending_settings_default")
+        type(system_mock.return_value.bios_settings.pending_settings).json = (
+            mock.PropertyMock(return_value=jsonval))
+        settings = jsonval.get('Attributes')
+        expected_value = {k: settings[k] for k in (
+            ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES) if k in settings}
+        actual_value = self.rf_client.get_pending_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected_value, actual_value)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_pending_bios_settings_filter_false(self, system_mock):
+
+        only_allowed_settings = False
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("BIOS_pending_settings_default")
+        type(system_mock.return_value.bios_settings.pending_settings).json = (
+            mock.PropertyMock(return_value=jsonval))
+        expected = jsonval.get('Attributes')
+        actual = self.rf_client.get_pending_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected, actual)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_pending_bios_settings_raises_exception(self, system_mock):
+
+        only_allowed_settings = True
+        bios_mock = mock.PropertyMock()
+        bios_mock.side_effect = sushy.exceptions.SushyError
+        type(system_mock.return_value.bios_settings.pending_settings).json = (
+            bios_mock)
+        self.assertRaisesRegex(
+            exception.IloError,
+            'The pending BIOS Settings were not found',
+            self.rf_client.get_pending_bios_settings,
+            only_allowed_settings)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_default_bios_settings_filter_true(self, get_system_mock):
+
+        only_allowed_settings = True
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("Default")
+        settings = jsonval.get("Attributes")
+        type(get_system_mock.return_value.bios_settings).default_settings = (
+            mock.PropertyMock(return_value=settings))
+        expected = {k: settings[k] for k in (
+            ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES) if k in settings}
+        actual = self.rf_client.get_default_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected, actual)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_default_bios_settings_filter_false(self, get_system_mock):
+
+        only_allowed_settings = False
+        with open('proliantutils/tests/redfish/'
+                  'json_samples/bios.json', 'r') as f:
+            jsonval = json.loads(f.read()).get("Default")
+        settings = jsonval.get("Attributes")
+        type(get_system_mock.return_value.bios_settings).default_settings = (
+            mock.PropertyMock(return_value=settings))
+        expected = settings
+        actual = self.rf_client.get_default_bios_settings(
+            only_allowed_settings)
+        self.assertEqual(expected, actual)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_default_bios_settings_raises_exception(self, get_system_mock):
+
+        only_allowed_settings = True
+        bios_mock = mock.PropertyMock(side_effect=sushy.exceptions.SushyError)
+        type(get_system_mock.return_value.bios_settings).default_settings = (
+            bios_mock)
+        self.assertRaisesRegex(
+            exception.IloError,
+            'The default BIOS Settings were not found',
+            self.rf_client.get_default_bios_settings,
+            only_allowed_settings)
+
+    @mock.patch.object(bios.BIOSPendingSettings, 'update_bios_data_by_patch')
+    @mock.patch.object(utils, 'apply_bios_properties_filter')
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_set_bios_settings_no_data(self, system_mock, bios_filter_mock,
+                                       update_data_mock):
+        data = None
+        apply_filter = True
+        pending_settings_mock = mock.PropertyMock()
+        type(system_mock.return_value.bios_settings).pending_settings = (
+            pending_settings_mock)
+        self.rf_client.set_bios_settings(data, apply_filter)
+        bios_filter_mock.assert_not_called()
+        pending_settings_mock.assert_not_called()
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_set_bios_settings_filter_true(self, system_mock):
+        apply_filter = True
+        data = {
+            "AdminName": "Administrator",
+            "BootMode": "LEGACY",
+            "ServerName": "Gen9 server",
+            "TimeFormat": "Ist",
+            "BootOrderPolicy": "RetryIndefinitely",
+            "ChannelInterleaving": "Enabled",
+            "CollabPowerControl": "Enabled",
+            "ConsistentDevNaming": "LomsOnly",
+            "CustomPostMessage": ""
+        }
+        expected = {k: data[k] for k in data if k in (
+            ilo_cons.SUPPORTED_REDFISH_BIOS_PROPERTIES)}
+        bios_ps_mock = mock.MagicMock(spec=bios.BIOSPendingSettings)
+        pending_settings_mock = mock.PropertyMock(return_value=bios_ps_mock)
+        type(system_mock.return_value.bios_settings).pending_settings = (
+            pending_settings_mock)
+
+        self.rf_client.set_bios_settings(data, apply_filter)
+        bios_ps_mock.update_bios_data_by_patch.assert_called_once_with(
+            expected)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_set_bios_settings_filter_false(self, system_mock):
+        apply_filter = False
+        data = {
+            "AdminName": "Administrator",
+            "BootMode": "LEGACY",
+            "ServerName": "Gen9 server",
+            "TimeFormat": "Ist",
+            "BootOrderPolicy": "RetryIndefinitely",
+            "ChannelInterleaving": "Enabled",
+            "CollabPowerControl": "Enabled",
+            "ConsistentDevNaming": "LomsOnly",
+            "CustomPostMessage": ""
+        }
+        bios_ps_mock = mock.MagicMock(spec=bios.BIOSPendingSettings)
+        pending_settings_mock = mock.PropertyMock(return_value=bios_ps_mock)
+        type(system_mock.return_value.bios_settings).pending_settings = (
+            pending_settings_mock)
+
+        self.rf_client.set_bios_settings(data, apply_filter)
+        bios_ps_mock.update_bios_data_by_patch.assert_called_once_with(data)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_set_bios_settings_raises_exception(self, system_mock):
+        apply_filter = True
+        data = {
+            "BootMode": "LEGACY",
+            "TimeFormat": "Ist",
+            "BootOrderPolicy": "RetryIndefinitely",
+            "CollabPowerControl": "Enabled",
+        }
+        pending_settings_mock = mock.PropertyMock(
+            side_effect=sushy.exceptions.SushyError)
+        type(system_mock.return_value.bios_settings).pending_settings = (
+            pending_settings_mock)
+        self.assertRaisesRegex(
+            exception.IloError,
+            'The pending BIOS Settings resource not found',
+            self.rf_client.set_bios_settings,
+            data,
+            apply_filter)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_get_host_post_state(self, get_system_mock):
+        post_state = mock.PropertyMock(return_value='poweroff')
+        type(get_system_mock.return_value).post_state = post_state
+        result = self.rf_client.get_host_post_state()
+        self.assertEqual('PowerOff', result)
+
+    @mock.patch.object(redfish.RedfishOperations, '_get_sushy_system')
+    def test_delete_raid_configuration(self, get_system_mock):
+        self.rf_client.delete_raid_configuration()
+        get_system_mock.return_value.delete_raid.assert_called_once_with()
